@@ -9,7 +9,7 @@ use Log::Any '$log';
 use DateTime;
 use Function::Fallback::CoreOrPP qw(clone);
 use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
-use Perinci::Sub::Util qw(err);
+use Perinci::Sub::Util qw(err gen_modified_sub);
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -19,8 +19,8 @@ our @EXPORT_OK = qw(
                        count_id_workdays
                );
 
-our $VERSION = '0.20'; # VERSION
-our $DATE = '2014-06-26'; # DATE
+our $VERSION = '0.22'; # VERSION
+our $DATE = '2014-08-06'; # DATE
 
 our %SPEC;
 my @fixed_holidays = (
@@ -585,6 +585,34 @@ $year_holidays{2014} = [
     _jointlv     ({_expand_dm("26-12")}, {holiday=>$christmas}),
 ];
 
+# decreed may 7, 2014
+#
+# Surat Keputusan Bersama Libur Nasional dan Cuti Bersama
+#
+# ref:
+# - http://nasional.kompas.com/read/2014/05/07/1805155/Hari.Libur.dan.Cuti.Bersama.2015.Banyak.Long.Weekend.dan.Harpitnas.3
+my $eidulf2015;
+$year_holidays{2015} = [
+    _h_mawlid    ({_expand_dm("03-01")}),
+    _h_chnewyear ({_expand_dm("19-02")}, {hyear=>2566}),
+    _h_nyepi     ({_expand_dm("21-03")}, {hyear=>1937}),
+    _h_goodfri   ({_expand_dm("03-04")}),
+    _h_ascension ({_expand_dm("14-05")}),
+    _h_isramiraj ({_expand_dm("16-05")}),
+    _h_vesakha   ({_expand_dm("02-06")}, {hyear=>2559}),
+
+    ($eidulf2015 =
+    _h_eidulf    ({_expand_dm("17-07")}, {hyear=>1436, day=>1}),
+    _h_eidulf    ({_expand_dm("18-07")}, {hyear=>1436, day=>2})),
+    _h_eidula    ({_expand_dm("24-09")}, {hyear=>1436}),
+    _h_hijra     ({_expand_dm("14-10")}, {hyear=>1437}),
+
+    _jointlv     ({_expand_dm("16-07")}, {holiday=>$eidulf2015}),
+    _jointlv     ({_expand_dm("20-07")}, {holiday=>$eidulf2015}),
+    _jointlv     ({_expand_dm("21-07")}, {holiday=>$eidulf2015}),
+    _jointlv     ({_expand_dm("24-12")}, {holiday=>$christmas}),
+];
+
 my @years     = sort keys %year_holidays;
 our $min_year = $years[0];
 our $max_year = $years[-1];
@@ -841,15 +869,18 @@ sub enum_id_workdays {
     [200, "OK", \@wd];
 }
 
-$meta = clone($SPEC{enum_id_workdays});
-$meta->{summary} = "Count working days for a certain period";
-$SPEC{count_id_workdays} = $meta;
-sub count_id_workdays {
-    my $res = enum_id_workdays(@_);
-    return $res unless $res->[0] == 200;
-    $res->[2] = @{$res->[2]};
-    $res;
-}
+gen_modified_sub(
+    output_name => 'count_id_workdays',
+    summary     => "Count working days for a certain period",
+
+    base_name   => 'enum_id_workdays',
+    output_code => sub {
+        my $res = enum_id_workdays(@_);
+        return $res unless $res->[0] == 200;
+        $res->[2] = @{$res->[2]};
+        $res;
+    },
+);
 
 1;
 # ABSTRACT: List Indonesian public holidays
@@ -866,7 +897,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.20 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2014-06-26.
+This document describes version 0.22 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2014-08-06.
 
 =head1 SYNOPSIS
 
@@ -944,13 +975,13 @@ This module has L<Rinci> metadata.
 
 Count working days for a certain period.
 
-Working day is defined as day that is not SaturdayI</Sunday/holiday/joint leave
-days>. If workI<saturdays is set to true, Saturdays are also counted as working
-days. If observe>joint_leaves is set to false, joint leave days are also counted
+Working day is defined as day that is not Saturday*/Sunday/holiday/joint leave
+days*. If work_saturdays is set to true, Saturdays are also counted as working
+days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2014 (joint leave days until
-2014).
+Contains data from years 2002 to 2015 (joint leave days until
+2015).
 
 Arguments ('*' denotes required arguments):
 
@@ -991,18 +1022,20 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 
 =head2 enum_id_workdays(%args) -> [status, msg, result, meta]
 
 Enumerate working days for a certain period.
 
-Working day is defined as day that is not SaturdayI</Sunday/holiday/joint leave
-days>. If workI<saturdays is set to true, Saturdays are also counted as working
-days. If observe>joint_leaves is set to false, joint leave days are also counted
+Working day is defined as day that is not Saturday*/Sunday/holiday/joint leave
+days*. If work_saturdays is set to true, Saturdays are also counted as working
+days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2014 (joint leave days until
-2014).
+Contains data from years 2002 to 2015 (joint leave days until
+2015).
 
 Arguments ('*' denotes required arguments):
 
@@ -1043,6 +1076,8 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 
 =head2 list_id_holidays(%args) -> [status, msg, result, meta]
 
@@ -1050,8 +1085,8 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 2002 to 2014 (joint leave days until
-2014).
+Contains data from years 2002 to 2015 (joint leave days until
+2015).
 
 Arguments ('*' denotes required arguments):
 
@@ -1467,6 +1502,8 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 FAQ
 
 =head2 What is "joint leave"?
